# Userdata Privacy

Cluster API Provider AWS bootstraps EC2 instances to create and join Kubernetes clusters using instance user data.
Because Kubernetes clusters are secured using TLS using multiple Certificate Authorities, these are generated by
Cluster API and injected into the user data. It is important to note that without the configuring of host firewalls, processes can
retrieve instance userdata from http://169.254.169.254/latest/api/token

## Requirements

* An AMI that includes the AWS CLI
* AMIs using CloudInit
* A working `/bin/bash` shell
* LFS directory layout (i.e. `/etc` exists and is readable by CloudInit)

[Listed AMIs](./images/built-amis.md) on 1.16 and up should include the AWS CLI.

## How Cluster API secures TLS secrets

Since v0.5.x, Cluster API Provider AWS has used [AWS Secrets Manager](https://aws.amazon.com/secrets-manager/)
as a limited-time secret store, storing the userdata using KMS encryption at rest in AWS.
The EC2 IMDS userdata will contain a boot script to download the encrypted userdata secret
using instance profile permissions, then immediately delete it from AWS Secrets Manager, and then execute it.

To avoid guessing keys in the AWS Secrets Manager key-value store and to prevent collisions, the key is an encoding the
Kubernetes namespace, cluster name and instance name, with a random string appended, providing ~256-bits of entropy.

Cluster API Provider AWS also stores the secret ARN in the AWSMachine spec, and will delete the secret if it isn't already deleted and
the machine has registered successfully against the workload cluster API server as a node.
Cluster API Provider AWS will also attempt deletion of the secret if the AWSMachine is otherwise deleted or the EC2 instance
is terminated or failed.

This method is only compatible with operating systems and distributions using
[cloud-init](https://cloudinit.readthedocs.io/en/latest/topics/format.html#mime-multi-part-archive). If you are using a different bootstrap
process, you will need to co-ordinate this externally and set the following in the specification of the AWSMachine types to disable the use
of a cloud-init boothook:

``` yaml
cloudInit:
  insecureSkipSecretsManager: true
```

## Troubleshooting

### Script errors

cloud-init does not print boothook script errors to the systemd journal. Logs for the script, if it errored can be found in
`/var/log/cloud-init-output.log`

### Warning messages

Because cloud-init will attempt to read the final file at start, cloud-init will always print a `/etc/secret-userdata.txt cannot be found`
message. This can be safely ignored.

### Secrets manager console

The AWS secrets manager console should show secrets being created and deleted, with a lifetime of around a minute. No plaintext secret
data will appear in the console as Cluster API Provider AWS stores the userdata as fragments of a gzipped data stream.
